@@ -7,7 +7,7 @@ use Catmandu::Fix::Has;
 
 with 'Catmandu::Fix::Inlineable';
 
-our $VERSION = '1.161';
+our $VERSION = '1.17';
 
 has marc_path      => (fix_arg => 1);
 has value          => (fix_arg => 1);
@@ -30,6 +30,9 @@ Catmandu::Fix::marc_set - set a marc value of one (sub)field to a new value
         marc_set('LDR/6','p')
     end
 
+    # Set a control field
+    marc_set('001',1234)
+
     # Set all the 650-p fields to 'test'
     marc_set('650p','test')
 
@@ -62,7 +65,10 @@ This Fix can be used inline in a Perl script:
 
 =head1 SEE ALSO
 
-L<Catmandu::Fix>
+L<Catmandu::Fix::marc_add>,
+L<Catmandu::Fix::marc_copy>,
+L<Catmandu::Fix::marc_cut>,
+L<Catmandu::Fix::marc_paste>
 
 =cut
 
