@@ -7,7 +7,7 @@ use Catmandu::Fix::Has;
 
 with 'Catmandu::Fix::Base';
 
-our $VERSION = '1.161';
+our $VERSION = '1.17';
 
 has spec          => ( fix_arg=> 1 );
 has path          => ( fix_arg=> 1 );
@@ -35,7 +35,7 @@ sub emit {
                             '-nested_arrays' => $self->nested_arrays // 0 ,
                             '-invert'      => $self->invert // 0 ,
                             '-value'       => $self->value ,
-                            '-force_array' => ($key =~ /^(\$.*|\d+)$/) ? 1 : 0
+                            '-force_array' => ($key =~ /^(\$.*|[0-9]+)$/) ? 1 : 0
                         });
 
     my $var          = $fixer->var;
